#include "struct_CPDD.h"
#include "struct_CPInfo.h"
#include "struct_OPArg.h"
#include "struct_SDir.h"

extern char *write_now;

extern void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
